Welcome to SQLSoup's documentation!
===================================

`SQLSoup <http://bitbucket.org/zzzeek/sqlsoup>`_ is a one step database access tool
built on top of the `SQLAlchemy <http://www.sqlalchemy.org>`_ Object Relational Mapper.

.. toctree::
   :maxdepth: 2

   front
   tutorial
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

